# MCP Architect Instructions

A structured guide for planning and implementing Model Context Protocol (MCP) servers in Python.

## Directory Structure

```
/mcp_architect_instructions/
├── README.md                         # This file
├── GETTING_STARTED.md                # Quick start guide
├── mcp_architecture_instructions.md  # Main planning process
├── guides/                           # Specialized guides
│   ├── environment_setup_guide.md    # Environment setup
│   ├── project_structure_guide.md    # Project organization
│   ├── implementation_guide.md       # Core patterns
│   ├── dependency_guide.md           # Managing dependencies
│   ├── logging_guide.md              # Logging practices
│   ├── registration_guide.md         # Server registration
│   ├── testing_guide.md              # Testing approach
│   └── reference_guide.md            # Additional resources
├── templates/                        # Reusable templates
│   ├── implementation_plan_template.md     # Plan template
│   ├── requirements_questionnaire.md       # Requirements guide
│   ├── task_template.md                    # Task definition
│   └── work_progress_log_template.md       # Progress tracking
└── examples/                         # Practical examples
    ├── weather_mcp_example.md              # Complete server
    ├── task_example.md                     # Task definition
    └── planning_example.md                 # Implementation plan
```

## How to Use

### For Planning (Architect Mode)

1. Start with [mcp_architecture_instructions.md](mcp_architecture_instructions.md) for the planning process
2. Follow the structured approach:
   - Gather requirements using [requirements_questionnaire.md](templates/requirements_questionnaire.md)
   - Define architecture and components
   - Create tasks using [task_template.md](templates/task_template.md)
   - Finalize the plan using [implementation_plan_template.md](templates/implementation_plan_template.md)
3. Reference specific guides from the [guides/](guides/) directory when needed

### For Implementation (Coder Mode)

1. Reference the completed implementation plan
2. Use guides in the [guides/](guides/) directory for implementation details
3. Refer to examples in the [examples/](examples/) directory
4. Track progress using the work progress log

## Getting Started

New to MCP development? See [GETTING_STARTED.md](GETTING_STARTED.md) for a quick orientation and walkthrough.